<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    webdav
 */

/**
 * Hook class.
 */
class Hook_addon_registry_webdav
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the current version of this addon (usually software major, software minor, addon build).
     * Put the comment "// addon_version_auto_update" to the right of the return if you want release tools to automatically update this according to software version and find_addon_effective_mtime.
     *
     * @return SHORT_TEXT Version number
     */
    public function get_version() : string
    {
        return '11.0.1'; // addon_version_auto_update b4ff29ab4c172f26e61cd687659fb0dc
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return 11.9;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Development';
    }

    /**
     * Get the addon author.
     *
     * @return string The author
     */
    public function get_author() : string
    {
        return 'Chris Graham';
    }

    /**
     * Find other authors.
     *
     * @return array A list of co-authors that should be attributed
     */
    public function get_copyright_attribution() : array
    {
        return [
            'SabreDAV developers',
        ];
    }

    /**
     * Get the addon licence (one-line summary only).
     *
     * @return string The licence
     */
    public function get_licence() : string
    {
        return 'BSD-like licence';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'Access your website repository as a folder on your computer. See the [url="' . get_brand_base_url() . '/docs/tut_repository.htm"]Repository Tutorial[/url] for more information. This addon is only tested with Apache, custom redirect configuration will be needed for IIS. This addon will NOT work with PHP 8 or higher.';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [
                'commandr',
                'PHP 7.1',
                'PHP mbstring extension',
            ],
            'recommends' => [],
            'conflicts_with' => [
                'PHP 8'
            ],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/admin/tool.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'data_custom/modules/webdav/index.html',
            'data_custom/modules/webdav/locks/index.html',
            'data_custom/modules/webdav/locks/locks.dat',
            'data_custom/modules/webdav/tmp/index.html',
            'data_custom/webdav.php',
            'sources_custom/hooks/systems/addon_registry/webdav.php',
            'sources_custom/sabredav/.htaccess',
            'sources_custom/sabredav/LICENSE',
            'sources_custom/sabredav/README.md',
            'sources_custom/sabredav/bin/.htaccess',
            'sources_custom/sabredav/bin/build.php',
            'sources_custom/sabredav/bin/googlecode_upload.py',
            'sources_custom/sabredav/bin/index.html',
            'sources_custom/sabredav/bin/migrateto20.php',
            'sources_custom/sabredav/bin/migrateto21.php',
            'sources_custom/sabredav/bin/migrateto30.php',
            'sources_custom/sabredav/bin/migrateto32.php',
            'sources_custom/sabredav/bin/naturalselection',
            'sources_custom/sabredav/bin/sabredav',
            'sources_custom/sabredav/bin/sabredav.php',
            'sources_custom/sabredav/composer.json',
            'sources_custom/sabredav/composer.lock',
            'sources_custom/sabredav/index.html',
            'sources_custom/sabredav/lib/CalDAV/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Backend/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Backend/AbstractBackend.php',
            'sources_custom/sabredav/lib/CalDAV/Backend/BackendInterface.php',
            'sources_custom/sabredav/lib/CalDAV/Backend/NotificationSupport.php',
            'sources_custom/sabredav/lib/CalDAV/Backend/PDO.php',
            'sources_custom/sabredav/lib/CalDAV/Backend/SchedulingSupport.php',
            'sources_custom/sabredav/lib/CalDAV/Backend/SharingSupport.php',
            'sources_custom/sabredav/lib/CalDAV/Backend/SimplePDO.php',
            'sources_custom/sabredav/lib/CalDAV/Backend/SubscriptionSupport.php',
            'sources_custom/sabredav/lib/CalDAV/Backend/SyncSupport.php',
            'sources_custom/sabredav/lib/CalDAV/Backend/index.html',
            'sources_custom/sabredav/lib/CalDAV/Calendar.php',
            'sources_custom/sabredav/lib/CalDAV/CalendarHome.php',
            'sources_custom/sabredav/lib/CalDAV/CalendarObject.php',
            'sources_custom/sabredav/lib/CalDAV/CalendarQueryValidator.php',
            'sources_custom/sabredav/lib/CalDAV/CalendarRoot.php',
            'sources_custom/sabredav/lib/CalDAV/Exception/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Exception/InvalidComponentType.php',
            'sources_custom/sabredav/lib/CalDAV/Exception/index.html',
            'sources_custom/sabredav/lib/CalDAV/ICSExportPlugin.php',
            'sources_custom/sabredav/lib/CalDAV/ICalendar.php',
            'sources_custom/sabredav/lib/CalDAV/ICalendarObject.php',
            'sources_custom/sabredav/lib/CalDAV/ICalendarObjectContainer.php',
            'sources_custom/sabredav/lib/CalDAV/ISharedCalendar.php',
            'sources_custom/sabredav/lib/CalDAV/Notifications/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Notifications/Collection.php',
            'sources_custom/sabredav/lib/CalDAV/Notifications/ICollection.php',
            'sources_custom/sabredav/lib/CalDAV/Notifications/INode.php',
            'sources_custom/sabredav/lib/CalDAV/Notifications/Node.php',
            'sources_custom/sabredav/lib/CalDAV/Notifications/Plugin.php',
            'sources_custom/sabredav/lib/CalDAV/Notifications/index.html',
            'sources_custom/sabredav/lib/CalDAV/Plugin.php',
            'sources_custom/sabredav/lib/CalDAV/Principal/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Principal/Collection.php',
            'sources_custom/sabredav/lib/CalDAV/Principal/IProxyRead.php',
            'sources_custom/sabredav/lib/CalDAV/Principal/IProxyWrite.php',
            'sources_custom/sabredav/lib/CalDAV/Principal/ProxyRead.php',
            'sources_custom/sabredav/lib/CalDAV/Principal/ProxyWrite.php',
            'sources_custom/sabredav/lib/CalDAV/Principal/User.php',
            'sources_custom/sabredav/lib/CalDAV/Principal/index.html',
            'sources_custom/sabredav/lib/CalDAV/Schedule/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Schedule/IInbox.php',
            'sources_custom/sabredav/lib/CalDAV/Schedule/IMipPlugin.php',
            'sources_custom/sabredav/lib/CalDAV/Schedule/IOutbox.php',
            'sources_custom/sabredav/lib/CalDAV/Schedule/ISchedulingObject.php',
            'sources_custom/sabredav/lib/CalDAV/Schedule/Inbox.php',
            'sources_custom/sabredav/lib/CalDAV/Schedule/Outbox.php',
            'sources_custom/sabredav/lib/CalDAV/Schedule/Plugin.php',
            'sources_custom/sabredav/lib/CalDAV/Schedule/SchedulingObject.php',
            'sources_custom/sabredav/lib/CalDAV/Schedule/index.html',
            'sources_custom/sabredav/lib/CalDAV/SharedCalendar.php',
            'sources_custom/sabredav/lib/CalDAV/SharingPlugin.php',
            'sources_custom/sabredav/lib/CalDAV/Subscriptions/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Subscriptions/ISubscription.php',
            'sources_custom/sabredav/lib/CalDAV/Subscriptions/Plugin.php',
            'sources_custom/sabredav/lib/CalDAV/Subscriptions/Subscription.php',
            'sources_custom/sabredav/lib/CalDAV/Subscriptions/index.html',
            'sources_custom/sabredav/lib/CalDAV/Xml/Filter/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Xml/Filter/CalendarData.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Filter/CompFilter.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Filter/ParamFilter.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Filter/PropFilter.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Filter/index.html',
            'sources_custom/sabredav/lib/CalDAV/Xml/Notification/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Xml/Notification/Invite.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Notification/InviteReply.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Notification/NotificationInterface.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Notification/SystemStatus.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Notification/index.html',
            'sources_custom/sabredav/lib/CalDAV/Xml/Property/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Xml/Property/AllowedSharingModes.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Property/EmailAddressSet.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Property/Invite.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Property/ScheduleCalendarTransp.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Property/SupportedCalendarComponentSet.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Property/SupportedCalendarData.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Property/SupportedCollationSet.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Property/index.html',
            'sources_custom/sabredav/lib/CalDAV/Xml/Request/.htaccess',
            'sources_custom/sabredav/lib/CalDAV/Xml/Request/CalendarMultiGetReport.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Request/CalendarQueryReport.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Request/FreeBusyQueryReport.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Request/InviteReply.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Request/MkCalendar.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Request/Share.php',
            'sources_custom/sabredav/lib/CalDAV/Xml/Request/index.html',
            'sources_custom/sabredav/lib/CalDAV/index.html',
            'sources_custom/sabredav/lib/CardDAV/.htaccess',
            'sources_custom/sabredav/lib/CardDAV/AddressBook.php',
            'sources_custom/sabredav/lib/CardDAV/AddressBookHome.php',
            'sources_custom/sabredav/lib/CardDAV/AddressBookRoot.php',
            'sources_custom/sabredav/lib/CardDAV/Backend/.htaccess',
            'sources_custom/sabredav/lib/CardDAV/Backend/AbstractBackend.php',
            'sources_custom/sabredav/lib/CardDAV/Backend/BackendInterface.php',
            'sources_custom/sabredav/lib/CardDAV/Backend/PDO.php',
            'sources_custom/sabredav/lib/CardDAV/Backend/SyncSupport.php',
            'sources_custom/sabredav/lib/CardDAV/Backend/index.html',
            'sources_custom/sabredav/lib/CardDAV/Card.php',
            'sources_custom/sabredav/lib/CardDAV/IAddressBook.php',
            'sources_custom/sabredav/lib/CardDAV/ICard.php',
            'sources_custom/sabredav/lib/CardDAV/IDirectory.php',
            'sources_custom/sabredav/lib/CardDAV/Plugin.php',
            'sources_custom/sabredav/lib/CardDAV/VCFExportPlugin.php',
            'sources_custom/sabredav/lib/CardDAV/Xml/Filter/.htaccess',
            'sources_custom/sabredav/lib/CardDAV/Xml/Filter/AddressData.php',
            'sources_custom/sabredav/lib/CardDAV/Xml/Filter/ParamFilter.php',
            'sources_custom/sabredav/lib/CardDAV/Xml/Filter/PropFilter.php',
            'sources_custom/sabredav/lib/CardDAV/Xml/Filter/index.html',
            'sources_custom/sabredav/lib/CardDAV/Xml/Property/.htaccess',
            'sources_custom/sabredav/lib/CardDAV/Xml/Property/SupportedAddressData.php',
            'sources_custom/sabredav/lib/CardDAV/Xml/Property/SupportedCollationSet.php',
            'sources_custom/sabredav/lib/CardDAV/Xml/Property/index.html',
            'sources_custom/sabredav/lib/CardDAV/Xml/Request/.htaccess',
            'sources_custom/sabredav/lib/CardDAV/Xml/Request/AddressBookMultiGetReport.php',
            'sources_custom/sabredav/lib/CardDAV/Xml/Request/AddressBookQueryReport.php',
            'sources_custom/sabredav/lib/CardDAV/Xml/Request/index.html',
            'sources_custom/sabredav/lib/CardDAV/index.html',
            'sources_custom/sabredav/lib/DAV/.htaccess',
            'sources_custom/sabredav/lib/DAV/Auth/.htaccess',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/.htaccess',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/AbstractBasic.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/AbstractBearer.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/AbstractDigest.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/Apache.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/BackendInterface.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/BasicCallBack.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/File.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/IMAP.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/PDO.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/PDOBasicAuth.php',
            'sources_custom/sabredav/lib/DAV/Auth/Backend/index.html',
            'sources_custom/sabredav/lib/DAV/Auth/Plugin.php',
            'sources_custom/sabredav/lib/DAV/Auth/index.html',
            'sources_custom/sabredav/lib/DAV/Browser/.htaccess',
            'sources_custom/sabredav/lib/DAV/Browser/GuessContentType.php',
            'sources_custom/sabredav/lib/DAV/Browser/HtmlOutput.php',
            'sources_custom/sabredav/lib/DAV/Browser/HtmlOutputHelper.php',
            'sources_custom/sabredav/lib/DAV/Browser/MapGetToPropFind.php',
            'sources_custom/sabredav/lib/DAV/Browser/Plugin.php',
            'sources_custom/sabredav/lib/DAV/Browser/PropFindAll.php',
            'sources_custom/sabredav/lib/DAV/Browser/assets/.htaccess',
            'sources_custom/sabredav/lib/DAV/Browser/assets/favicon.ico',
            'sources_custom/sabredav/lib/DAV/Browser/assets/index.html',
            'sources_custom/sabredav/lib/DAV/Browser/assets/openiconic/.htaccess',
            'sources_custom/sabredav/lib/DAV/Browser/assets/openiconic/ICON-LICENSE',
            'sources_custom/sabredav/lib/DAV/Browser/assets/openiconic/index.html',
            'sources_custom/sabredav/lib/DAV/Browser/assets/openiconic/open-iconic.css',
            'sources_custom/sabredav/lib/DAV/Browser/assets/openiconic/open-iconic.eot',
            'sources_custom/sabredav/lib/DAV/Browser/assets/openiconic/open-iconic.otf',
            'sources_custom/sabredav/lib/DAV/Browser/assets/openiconic/open-iconic.svg',
            'sources_custom/sabredav/lib/DAV/Browser/assets/openiconic/open-iconic.ttf',
            'sources_custom/sabredav/lib/DAV/Browser/assets/openiconic/open-iconic.woff',
            'sources_custom/sabredav/lib/DAV/Browser/assets/sabredav.css',
            'sources_custom/sabredav/lib/DAV/Browser/assets/sabredav.png',
            'sources_custom/sabredav/lib/DAV/Browser/index.html',
            'sources_custom/sabredav/lib/DAV/Client.php',
            'sources_custom/sabredav/lib/DAV/Collection.php',
            'sources_custom/sabredav/lib/DAV/CorePlugin.php',
            'sources_custom/sabredav/lib/DAV/Exception.php',
            'sources_custom/sabredav/lib/DAV/Exception/.htaccess',
            'sources_custom/sabredav/lib/DAV/Exception/BadRequest.php',
            'sources_custom/sabredav/lib/DAV/Exception/Conflict.php',
            'sources_custom/sabredav/lib/DAV/Exception/ConflictingLock.php',
            'sources_custom/sabredav/lib/DAV/Exception/Forbidden.php',
            'sources_custom/sabredav/lib/DAV/Exception/InsufficientStorage.php',
            'sources_custom/sabredav/lib/DAV/Exception/InvalidResourceType.php',
            'sources_custom/sabredav/lib/DAV/Exception/InvalidSyncToken.php',
            'sources_custom/sabredav/lib/DAV/Exception/LengthRequired.php',
            'sources_custom/sabredav/lib/DAV/Exception/LockTokenMatchesRequestUri.php',
            'sources_custom/sabredav/lib/DAV/Exception/Locked.php',
            'sources_custom/sabredav/lib/DAV/Exception/MethodNotAllowed.php',
            'sources_custom/sabredav/lib/DAV/Exception/NotAuthenticated.php',
            'sources_custom/sabredav/lib/DAV/Exception/NotFound.php',
            'sources_custom/sabredav/lib/DAV/Exception/NotImplemented.php',
            'sources_custom/sabredav/lib/DAV/Exception/PaymentRequired.php',
            'sources_custom/sabredav/lib/DAV/Exception/PreconditionFailed.php',
            'sources_custom/sabredav/lib/DAV/Exception/ReportNotSupported.php',
            'sources_custom/sabredav/lib/DAV/Exception/RequestedRangeNotSatisfiable.php',
            'sources_custom/sabredav/lib/DAV/Exception/ServiceUnavailable.php',
            'sources_custom/sabredav/lib/DAV/Exception/TooManyMatches.php',
            'sources_custom/sabredav/lib/DAV/Exception/UnsupportedMediaType.php',
            'sources_custom/sabredav/lib/DAV/Exception/index.html',
            'sources_custom/sabredav/lib/DAV/FS/Directory.php',
            'sources_custom/sabredav/lib/DAV/FS/File.php',
            'sources_custom/sabredav/lib/DAV/FS/Node.php',
            'sources_custom/sabredav/lib/DAV/FSExt/.htaccess',
            'sources_custom/sabredav/lib/DAV/FSExt/Directory.php',
            'sources_custom/sabredav/lib/DAV/FSExt/File.php',
            'sources_custom/sabredav/lib/DAV/FSExt/index.html',
            'sources_custom/sabredav/lib/DAV/File.php',
            'sources_custom/sabredav/lib/DAV/ICollection.php',
            'sources_custom/sabredav/lib/DAV/ICopyTarget.php',
            'sources_custom/sabredav/lib/DAV/IExtendedCollection.php',
            'sources_custom/sabredav/lib/DAV/IFile.php',
            'sources_custom/sabredav/lib/DAV/IMoveTarget.php',
            'sources_custom/sabredav/lib/DAV/IMultiGet.php',
            'sources_custom/sabredav/lib/DAV/INode.php',
            'sources_custom/sabredav/lib/DAV/INodeByPath.php',
            'sources_custom/sabredav/lib/DAV/IProperties.php',
            'sources_custom/sabredav/lib/DAV/IQuota.php',
            'sources_custom/sabredav/lib/DAV/Locks/.htaccess',
            'sources_custom/sabredav/lib/DAV/Locks/Backend/.htaccess',
            'sources_custom/sabredav/lib/DAV/Locks/Backend/AbstractBackend.php',
            'sources_custom/sabredav/lib/DAV/Locks/Backend/BackendInterface.php',
            'sources_custom/sabredav/lib/DAV/Locks/Backend/File.php',
            'sources_custom/sabredav/lib/DAV/Locks/Backend/PDO.php',
            'sources_custom/sabredav/lib/DAV/Locks/Backend/index.html',
            'sources_custom/sabredav/lib/DAV/Locks/LockInfo.php',
            'sources_custom/sabredav/lib/DAV/Locks/Plugin.php',
            'sources_custom/sabredav/lib/DAV/Locks/index.html',
            'sources_custom/sabredav/lib/DAV/MkCol.php',
            'sources_custom/sabredav/lib/DAV/Mount/.htaccess',
            'sources_custom/sabredav/lib/DAV/Mount/Plugin.php',
            'sources_custom/sabredav/lib/DAV/Mount/index.html',
            'sources_custom/sabredav/lib/DAV/Node.php',
            'sources_custom/sabredav/lib/DAV/PartialUpdate/.htaccess',
            'sources_custom/sabredav/lib/DAV/PartialUpdate/IPatchSupport.php',
            'sources_custom/sabredav/lib/DAV/PartialUpdate/Plugin.php',
            'sources_custom/sabredav/lib/DAV/PartialUpdate/index.html',
            'sources_custom/sabredav/lib/DAV/PropFind.php',
            'sources_custom/sabredav/lib/DAV/PropPatch.php',
            'sources_custom/sabredav/lib/DAV/PropertyStorage/.htaccess',
            'sources_custom/sabredav/lib/DAV/PropertyStorage/Backend/.htaccess',
            'sources_custom/sabredav/lib/DAV/PropertyStorage/Backend/BackendInterface.php',
            'sources_custom/sabredav/lib/DAV/PropertyStorage/Backend/PDO.php',
            'sources_custom/sabredav/lib/DAV/PropertyStorage/Backend/index.html',
            'sources_custom/sabredav/lib/DAV/PropertyStorage/Plugin.php',
            'sources_custom/sabredav/lib/DAV/PropertyStorage/index.html',
            'sources_custom/sabredav/lib/DAV/Server.php',
            'sources_custom/sabredav/lib/DAV/ServerPlugin.php',
            'sources_custom/sabredav/lib/DAV/Sharing/.htaccess',
            'sources_custom/sabredav/lib/DAV/Sharing/ISharedNode.php',
            'sources_custom/sabredav/lib/DAV/Sharing/Plugin.php',
            'sources_custom/sabredav/lib/DAV/Sharing/index.html',
            'sources_custom/sabredav/lib/DAV/SimpleCollection.php',
            'sources_custom/sabredav/lib/DAV/SimpleFile.php',
            'sources_custom/sabredav/lib/DAV/StringUtil.php',
            'sources_custom/sabredav/lib/DAV/Sync/.htaccess',
            'sources_custom/sabredav/lib/DAV/Sync/ISyncCollection.php',
            'sources_custom/sabredav/lib/DAV/Sync/Plugin.php',
            'sources_custom/sabredav/lib/DAV/Sync/index.html',
            'sources_custom/sabredav/lib/DAV/TemporaryFileFilterPlugin.php',
            'sources_custom/sabredav/lib/DAV/Tree.php',
            'sources_custom/sabredav/lib/DAV/UUIDUtil.php',
            'sources_custom/sabredav/lib/DAV/Version.php',
            'sources_custom/sabredav/lib/DAV/Xml/.htaccess',
            'sources_custom/sabredav/lib/DAV/Xml/Element/.htaccess',
            'sources_custom/sabredav/lib/DAV/Xml/Element/Prop.php',
            'sources_custom/sabredav/lib/DAV/Xml/Element/Response.php',
            'sources_custom/sabredav/lib/DAV/Xml/Element/Sharee.php',
            'sources_custom/sabredav/lib/DAV/Xml/Element/index.html',
            'sources_custom/sabredav/lib/DAV/Xml/Property/.htaccess',
            'sources_custom/sabredav/lib/DAV/Xml/Property/Complex.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/GetLastModified.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/Href.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/Invite.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/LocalHref.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/LockDiscovery.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/ResourceType.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/ShareAccess.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/SupportedLock.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/SupportedMethodSet.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/SupportedReportSet.php',
            'sources_custom/sabredav/lib/DAV/Xml/Property/index.html',
            'sources_custom/sabredav/lib/DAV/Xml/Request/.htaccess',
            'sources_custom/sabredav/lib/DAV/Xml/Request/Lock.php',
            'sources_custom/sabredav/lib/DAV/Xml/Request/MkCol.php',
            'sources_custom/sabredav/lib/DAV/Xml/Request/PropFind.php',
            'sources_custom/sabredav/lib/DAV/Xml/Request/PropPatch.php',
            'sources_custom/sabredav/lib/DAV/Xml/Request/ShareResource.php',
            'sources_custom/sabredav/lib/DAV/Xml/Request/SyncCollectionReport.php',
            'sources_custom/sabredav/lib/DAV/Xml/Request/index.html',
            'sources_custom/sabredav/lib/DAV/Xml/Response/.htaccess',
            'sources_custom/sabredav/lib/DAV/Xml/Response/MultiStatus.php',
            'sources_custom/sabredav/lib/DAV/Xml/Response/index.html',
            'sources_custom/sabredav/lib/DAV/Xml/Service.php',
            'sources_custom/sabredav/lib/DAV/Xml/index.html',
            'sources_custom/sabredav/lib/DAV/index.html',
            'sources_custom/sabredav/lib/DAVACL/.htaccess',
            'sources_custom/sabredav/lib/DAVACL/ACLTrait.php',
            'sources_custom/sabredav/lib/DAVACL/AbstractPrincipalCollection.php',
            'sources_custom/sabredav/lib/DAVACL/Exception/.htaccess',
            'sources_custom/sabredav/lib/DAVACL/Exception/AceConflict.php',
            'sources_custom/sabredav/lib/DAVACL/Exception/NeedPrivileges.php',
            'sources_custom/sabredav/lib/DAVACL/Exception/NoAbstract.php',
            'sources_custom/sabredav/lib/DAVACL/Exception/NotRecognizedPrincipal.php',
            'sources_custom/sabredav/lib/DAVACL/Exception/NotSupportedPrivilege.php',
            'sources_custom/sabredav/lib/DAVACL/Exception/index.html',
            'sources_custom/sabredav/lib/DAVACL/FS/Collection.php',
            'sources_custom/sabredav/lib/DAVACL/FS/File.php',
            'sources_custom/sabredav/lib/DAVACL/FS/HomeCollection.php',
            'sources_custom/sabredav/lib/DAVACL/IACL.php',
            'sources_custom/sabredav/lib/DAVACL/IPrincipal.php',
            'sources_custom/sabredav/lib/DAVACL/IPrincipalCollection.php',
            'sources_custom/sabredav/lib/DAVACL/Plugin.php',
            'sources_custom/sabredav/lib/DAVACL/Principal.php',
            'sources_custom/sabredav/lib/DAVACL/PrincipalBackend/.htaccess',
            'sources_custom/sabredav/lib/DAVACL/PrincipalBackend/AbstractBackend.php',
            'sources_custom/sabredav/lib/DAVACL/PrincipalBackend/BackendInterface.php',
            'sources_custom/sabredav/lib/DAVACL/PrincipalBackend/CreatePrincipalSupport.php',
            'sources_custom/sabredav/lib/DAVACL/PrincipalBackend/PDO.php',
            'sources_custom/sabredav/lib/DAVACL/PrincipalBackend/index.html',
            'sources_custom/sabredav/lib/DAVACL/PrincipalCollection.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Property/.htaccess',
            'sources_custom/sabredav/lib/DAVACL/Xml/Property/Acl.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Property/AclRestrictions.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Property/CurrentUserPrivilegeSet.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Property/Principal.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Property/SupportedPrivilegeSet.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Property/index.html',
            'sources_custom/sabredav/lib/DAVACL/Xml/Request/.htaccess',
            'sources_custom/sabredav/lib/DAVACL/Xml/Request/AclPrincipalPropSetReport.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Request/ExpandPropertyReport.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Request/PrincipalMatchReport.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Request/PrincipalPropertySearchReport.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Request/PrincipalSearchPropertySetReport.php',
            'sources_custom/sabredav/lib/DAVACL/Xml/Request/index.html',
            'sources_custom/sabredav/lib/DAVACL/index.html',
            'sources_custom/sabredav/vendor/.htaccess',
            'sources_custom/sabredav/vendor/autoload.php',
            'sources_custom/sabredav/vendor/bin/.htaccess',
            'sources_custom/sabredav/vendor/bin/generate_vcards',
            'sources_custom/sabredav/vendor/bin/generate_vcards.bat',
            'sources_custom/sabredav/vendor/bin/index.html',
            'sources_custom/sabredav/vendor/bin/vobject',
            'sources_custom/sabredav/vendor/bin/vobject.bat',
            'sources_custom/sabredav/vendor/composer/.htaccess',
            'sources_custom/sabredav/vendor/composer/ClassLoader.php',
            'sources_custom/sabredav/vendor/composer/InstalledVersions.php',
            'sources_custom/sabredav/vendor/composer/LICENSE',
            'sources_custom/sabredav/vendor/composer/autoload_classmap.php',
            'sources_custom/sabredav/vendor/composer/autoload_files.php',
            'sources_custom/sabredav/vendor/composer/autoload_namespaces.php',
            'sources_custom/sabredav/vendor/composer/autoload_psr4.php',
            'sources_custom/sabredav/vendor/composer/autoload_real.php',
            'sources_custom/sabredav/vendor/composer/autoload_static.php',
            'sources_custom/sabredav/vendor/composer/index.html',
            'sources_custom/sabredav/vendor/composer/installed.json',
            'sources_custom/sabredav/vendor/composer/installed.php',
            'sources_custom/sabredav/vendor/composer/platform_check.php',
            'sources_custom/sabredav/vendor/index.html',
            'sources_custom/sabredav/vendor/psr/log/.htaccess',
            'sources_custom/sabredav/vendor/psr/log/LICENSE',
            'sources_custom/sabredav/vendor/psr/log/README.md',
            'sources_custom/sabredav/vendor/psr/log/composer.json',
            'sources_custom/sabredav/vendor/psr/log/index.html',
            'sources_custom/sabredav/vendor/psr/log/src/.htaccess',
            'sources_custom/sabredav/vendor/psr/log/src/AbstractLogger.php',
            'sources_custom/sabredav/vendor/psr/log/src/InvalidArgumentException.php',
            'sources_custom/sabredav/vendor/psr/log/src/LogLevel.php',
            'sources_custom/sabredav/vendor/psr/log/src/LoggerAwareInterface.php',
            'sources_custom/sabredav/vendor/psr/log/src/LoggerAwareTrait.php',
            'sources_custom/sabredav/vendor/psr/log/src/LoggerInterface.php',
            'sources_custom/sabredav/vendor/psr/log/src/LoggerTrait.php',
            'sources_custom/sabredav/vendor/psr/log/src/NullLogger.php',
            'sources_custom/sabredav/vendor/psr/log/src/index.html',
            'sources_custom/sabredav/vendor/sabre/event/.htaccess',
            'sources_custom/sabredav/vendor/sabre/event/.php-cs-fixer.dist.php',
            'sources_custom/sabredav/vendor/sabre/event/LICENSE',
            'sources_custom/sabredav/vendor/sabre/event/composer.json',
            'sources_custom/sabredav/vendor/sabre/event/index.html',
            'sources_custom/sabredav/vendor/sabre/event/lib/.htaccess',
            'sources_custom/sabredav/vendor/sabre/event/lib/Emitter.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/EmitterInterface.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/EmitterTrait.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/EventEmitter.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/Loop/.htaccess',
            'sources_custom/sabredav/vendor/sabre/event/lib/Loop/Loop.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/Loop/functions.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/Loop/index.html',
            'sources_custom/sabredav/vendor/sabre/event/lib/Promise.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/Promise/.htaccess',
            'sources_custom/sabredav/vendor/sabre/event/lib/Promise/functions.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/Promise/index.html',
            'sources_custom/sabredav/vendor/sabre/event/lib/PromiseAlreadyResolvedException.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/Version.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/WildcardEmitter.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/WildcardEmitterTrait.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/coroutine.php',
            'sources_custom/sabredav/vendor/sabre/event/lib/index.html',
            'sources_custom/sabredav/vendor/sabre/http/.github/workflows/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/.github/workflows/ci.yml',
            'sources_custom/sabredav/vendor/sabre/http/.github/workflows/index.html',
            'sources_custom/sabredav/vendor/sabre/http/.gitignore',
            'sources_custom/sabredav/vendor/sabre/http/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/.php-cs-fixer.dist.php',
            'sources_custom/sabredav/vendor/sabre/http/.php_cs.dist',
            'sources_custom/sabredav/vendor/sabre/http/CHANGELOG.md',
            'sources_custom/sabredav/vendor/sabre/http/LICENSE',
            'sources_custom/sabredav/vendor/sabre/http/README.md',
            'sources_custom/sabredav/vendor/sabre/http/bin/.empty',
            'sources_custom/sabredav/vendor/sabre/http/bin/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/bin/index.html',
            'sources_custom/sabredav/vendor/sabre/http/composer.json',
            'sources_custom/sabredav/vendor/sabre/http/examples/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/examples/asyncclient.php',
            'sources_custom/sabredav/vendor/sabre/http/examples/basicauth.php',
            'sources_custom/sabredav/vendor/sabre/http/examples/client.php',
            'sources_custom/sabredav/vendor/sabre/http/examples/digestauth.php',
            'sources_custom/sabredav/vendor/sabre/http/examples/index.html',
            'sources_custom/sabredav/vendor/sabre/http/examples/reverseproxy.php',
            'sources_custom/sabredav/vendor/sabre/http/examples/stringify.php',
            'sources_custom/sabredav/vendor/sabre/http/index.html',
            'sources_custom/sabredav/vendor/sabre/http/lib/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/lib/Auth/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/lib/Auth/AWS.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Auth/AbstractAuth.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Auth/Basic.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Auth/Bearer.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Auth/Digest.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Auth/index.html',
            'sources_custom/sabredav/vendor/sabre/http/lib/Client.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/ClientException.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/ClientHttpException.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/HttpException.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Message.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/MessageDecoratorTrait.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/MessageInterface.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Request.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/RequestDecorator.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/RequestInterface.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Response.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/ResponseDecorator.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/ResponseInterface.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Sapi.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/Version.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/functions.php',
            'sources_custom/sabredav/vendor/sabre/http/lib/index.html',
            'sources_custom/sabredav/vendor/sabre/http/phpstan.neon',
            'sources_custom/sabredav/vendor/sabre/http/tests/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/Auth/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/Auth/AWSTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/Auth/BasicTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/Auth/BearerTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/Auth/DigestTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/Auth/index.html',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/ClientTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/FunctionsTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/MessageDecoratorTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/MessageTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/NegotiateTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/RequestDecoratorTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/RequestTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/ResponseDecoratorTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/ResponseTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/SapiTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/URLUtilTest.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/HTTP/index.html',
            'sources_custom/sabredav/vendor/sabre/http/tests/bootstrap.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/index.html',
            'sources_custom/sabredav/vendor/sabre/http/tests/phpunit.xml',
            'sources_custom/sabredav/vendor/sabre/http/tests/www/.htaccess',
            'sources_custom/sabredav/vendor/sabre/http/tests/www/bar.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/www/connection_aborted.php',
            'sources_custom/sabredav/vendor/sabre/http/tests/www/foo',
            'sources_custom/sabredav/vendor/sabre/http/tests/www/index.html',
            'sources_custom/sabredav/vendor/sabre/http/tests/www/large.php',
            'sources_custom/sabredav/vendor/sabre/uri/.htaccess',
            'sources_custom/sabredav/vendor/sabre/uri/.php-cs-fixer.dist.php',
            'sources_custom/sabredav/vendor/sabre/uri/LICENSE',
            'sources_custom/sabredav/vendor/sabre/uri/composer.json',
            'sources_custom/sabredav/vendor/sabre/uri/index.html',
            'sources_custom/sabredav/vendor/sabre/uri/lib/.htaccess',
            'sources_custom/sabredav/vendor/sabre/uri/lib/InvalidUriException.php',
            'sources_custom/sabredav/vendor/sabre/uri/lib/Version.php',
            'sources_custom/sabredav/vendor/sabre/uri/lib/functions.php',
            'sources_custom/sabredav/vendor/sabre/uri/lib/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/LICENSE',
            'sources_custom/sabredav/vendor/sabre/vobject/README.md',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/bench.php',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/bench_freebusygenerator.php',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/bench_manipulatevcard.php',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/fetch_windows_zones.php',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/generate_vcards',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/generateicalendardata.php',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/mergeduplicates.php',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/rrulebench.php',
            'sources_custom/sabredav/vendor/sabre/vobject/bin/vobject',
            'sources_custom/sabredav/vendor/sabre/vobject/composer.json',
            'sources_custom/sabredav/vendor/sabre/vobject/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/BirthdayCalendarGenerator.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Cli.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/Available.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/VAlarm.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/VAvailability.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/VCalendar.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/VCard.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/VEvent.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/VFreeBusy.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/VJournal.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/VTimeZone.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/VTodo.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Component/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/DateTimeParser.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Document.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/ElementList.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/EofException.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/FreeBusyData.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/FreeBusyGenerator.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/ITip/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/ITip/Broker.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/ITip/ITipException.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/ITip/Message.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/ITip/SameOrganizerForAllComponentsException.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/ITip/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/InvalidDataException.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Node.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/PHPUnitAssertions.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parameter.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/ParseException.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parser/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parser/Json.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parser/MimeDir.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parser/Parser.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parser/XML.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parser/XML/Element/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parser/XML/Element/KeyValue.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parser/XML/Element/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Parser/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/Binary.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/Boolean.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/FlatText.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/FloatValue.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/ICalendar/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/ICalendar/CalAddress.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/ICalendar/Date.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/ICalendar/DateTime.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/ICalendar/Duration.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/ICalendar/Period.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/ICalendar/Recur.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/ICalendar/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/IntegerValue.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/Text.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/Time.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/Unknown.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/Uri.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/UtcOffset.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/VCard/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/VCard/Date.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/VCard/DateAndOrTime.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/VCard/DateTime.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/VCard/LanguageTag.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/VCard/PhoneNumber.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/VCard/TimeStamp.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/VCard/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Property/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Reader.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Recur/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Recur/EventIterator.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Recur/MaxInstancesExceededException.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Recur/NoInstancesException.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Recur/RDateIterator.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Recur/RRuleIterator.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Recur/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Settings.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Splitter/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Splitter/ICalendar.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Splitter/SplitterInterface.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Splitter/VCard.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Splitter/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/StringUtil.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimeZoneUtil.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimezoneGuesser/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimezoneGuesser/FindFromOffset.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimezoneGuesser/FindFromTimezoneIdentifier.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimezoneGuesser/FindFromTimezoneMap.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimezoneGuesser/GuessFromLicEntry.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimezoneGuesser/GuessFromMsTzId.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimezoneGuesser/TimezoneFinder.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimezoneGuesser/TimezoneGuesser.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/TimezoneGuesser/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/UUIDUtil.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/VCardConverter.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Version.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/Writer.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/timezonedata/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/timezonedata/exchangezones.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/timezonedata/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/timezonedata/lotuszones.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/timezonedata/php-bc.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/timezonedata/php-workaround.php',
            'sources_custom/sabredav/vendor/sabre/vobject/lib/timezonedata/windowszones.php',
            'sources_custom/sabredav/vendor/sabre/vobject/resources/schema/.htaccess',
            'sources_custom/sabredav/vendor/sabre/vobject/resources/schema/index.html',
            'sources_custom/sabredav/vendor/sabre/vobject/resources/schema/xcal.rng',
            'sources_custom/sabredav/vendor/sabre/vobject/resources/schema/xcard.rng',
            'sources_custom/sabredav/vendor/sabre/xml/.github/workflows/.htaccess',
            'sources_custom/sabredav/vendor/sabre/xml/.github/workflows/ci.yml',
            'sources_custom/sabredav/vendor/sabre/xml/.github/workflows/index.html',
            'sources_custom/sabredav/vendor/sabre/xml/.htaccess',
            'sources_custom/sabredav/vendor/sabre/xml/.php-cs-fixer.dist.php',
            'sources_custom/sabredav/vendor/sabre/xml/LICENSE',
            'sources_custom/sabredav/vendor/sabre/xml/README.md',
            'sources_custom/sabredav/vendor/sabre/xml/bin/.empty',
            'sources_custom/sabredav/vendor/sabre/xml/bin/.htaccess',
            'sources_custom/sabredav/vendor/sabre/xml/bin/index.html',
            'sources_custom/sabredav/vendor/sabre/xml/composer.json',
            'sources_custom/sabredav/vendor/sabre/xml/index.html',
            'sources_custom/sabredav/vendor/sabre/xml/lib/.htaccess',
            'sources_custom/sabredav/vendor/sabre/xml/lib/ContextStackTrait.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Deserializer/.htaccess',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Deserializer/functions.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Deserializer/index.html',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Element.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Element/.htaccess',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Element/Base.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Element/Cdata.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Element/Elements.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Element/KeyValue.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Element/Uri.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Element/XmlFragment.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Element/index.html',
            'sources_custom/sabredav/vendor/sabre/xml/lib/LibXMLException.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/ParseException.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Reader.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Serializer/.htaccess',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Serializer/functions.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Serializer/index.html',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Service.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Version.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/Writer.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/XmlDeserializable.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/XmlSerializable.php',
            'sources_custom/sabredav/vendor/sabre/xml/lib/index.html',
            'sources_custom/webdav.php',
            'sources_custom/webdav_commandr_fs.php',
        ];
    }
}
